==> igniteui-webcomponents-core-3.2.4.tgz: package/esm2015/lib/ToolActionIconButtonDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionIconButtonDescription } from "./ToolActionIconButtonDescription";
/**
 * @hidden
 */
export let ToolActionIconButtonDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionIconButtonDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionIconButtonDescriptionMetadata.a == null) {
                ToolActionIconButtonDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionIconButtonDescriptionMetadata.c(ToolActionIconButtonDescriptionMetadata.a);
            }
            if (a.g(ToolActionIconButtonDescriptionMetadata.a)) {
                return;
            }
            a.s(ToolActionIconButtonDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionDescriptionMetadata.c(a);
        }
        static d(a) {
            ToolActionIconButtonDescriptionMetadata.b(a);
            a.u("ToolActionIconButton", () => new ToolActionIconButtonDescription());
            a.t("ToolActionIconButton", ToolActionIconButtonDescriptionMetadata.a);
        }
    }
    ToolActionIconButtonDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolActionIconButtonDescriptionMetadata, 'ToolActionIconButtonDescriptionMetadata');
    ToolActionIconButtonDescriptionMetadata.a = null;
    return ToolActionIconButtonDescriptionMetadata;
})();

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/ToolActionIconButtonDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionIconButtonDescription } from "./ToolActionIconButtonDescription";
/**
 * @hidden
 */
export let ToolActionIconButtonDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionIconButtonDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionIconButtonDescriptionMetadata.a == null) {
                ToolActionIconButtonDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionIconButtonDescriptionMetadata.c(ToolActionIconButtonDescriptionMetadata.a);
            }
            if (a.j(ToolActionIconButtonDescriptionMetadata.a)) {
                return;
            }
            a.y(ToolActionIconButtonDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionDescriptionMetadata.c(a);
        }
        static d(a) {
            ToolActionIconButtonDescriptionMetadata.b(a);
            a.aa("ToolActionIconButton", () => new ToolActionIconButtonDescription());
            a.z("ToolActionIconButton", ToolActionIconButtonDescriptionMetadata.a);
        }
    }
    ToolActionIconButtonDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolActionIconButtonDescriptionMetadata, 'ToolActionIconButtonDescriptionMetadata');
    ToolActionIconButtonDescriptionMetadata.a = null;
    return ToolActionIconButtonDescriptionMetadata;
})();
